LLM client for AI-assisted fix generation.
Sends code snippets + violation messages to an LLM endpoint and parses the response into text edits.
Functions
- request_
llm_ fix - Send an LLM fix request and return planned fixes.
LLM client for AI-assisted fix generation.
Sends code snippets + violation messages to an LLM endpoint and parses the response into text edits.